@@ -83,7 +83,14 @@ lazy_static! {
     };
 
     static ref DB_PROPERTIES: HashMap<String, String> = {
-        let filepath = "resources/application.properties";
+
+        let runtime_profile = "RUNTIME_PROFILE";
+        let env = match std::env::var(runtime_profile) {
+            Ok(t) => format!("-{}", t),
+            Err(_) => String::new(),
+        };
+
+        let filepath = format!("resources/application{}.properties", env);
         let contents = fs::read_to_string(filepath).expect("Something went wrong reading the file");
         let mut map = HashMap::new();
 
