@@ -26,20 +26,12 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
 
     for(key, value) in arg {
 
-
-        // let re_key = Regex::new(format!("(?i):{}( |$|\t|\r|\n)", key).as_str()).unwrap();
-        // let re_key2 = Regex::new(format!("(?i):{}\\)", key).as_str()).unwrap();
-        // let re_key3 = Regex::new(format!("(?i):{},", key).as_str()).unwrap();
-
         if let Value::String(m) = &value {
 
             let n = m.replace("'", "''");
             sql = sql.replace(&format!("#{}#", key), &format!("'{}'", n));
             sql = sql.replace(&format!(":{}", key), &format!("'{}'", n));
 
-            // sql = re_key.replace_all(&sql, format!("'{}'\n", m.replace("'","''")).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("'{}')", m.replace("'","''")).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("'{}',", m.replace("'","''")).as_str()).to_string();
         }
         if let Value::StringLikeLeft(m) = &value {
 
@@ -47,7 +39,6 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             sql = sql.replace(&format!("#{}#", key), &format!("'%{}'", n));
             sql = sql.replace(&format!(":{}", key), &format!("'%{}'", n));
 
-            // sql = re_key.replace_all(&sql, format!("'%{}'\n", m).as_str()).to_string();
         }
         if let Value::StringLikeRight(m) = &value {
 
@@ -55,7 +46,6 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             sql = sql.replace(&format!("#{}#", key), &format!("'{}%'", n));
             sql = sql.replace(&format!(":{}", key), &format!("'{}%'", n));
 
-            // sql = re_key.replace_all(&sql, format!("'{}%'\n", m).as_str()).to_string();
         }
         if let Value::StringLikeBoth(m) = &value {
 
@@ -63,39 +53,35 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             sql = sql.replace(&format!("#{}#", key), &format!("'%{}%'", n));
             sql = sql.replace(&format!(":{}", key), &format!("'%{}%'", n));
 
-            // sql = re_key.replace_all(&sql, format!("'%{}%'\n", m).as_str()).to_string();
         }
         if let Value::Float(m) = &value {
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key),&format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{}\n", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
+        }
+        if let Value::Float32(m) = &value {
+            sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
+            sql = sql.replace(&format!(":{}", key),&format!("{}", m));
         }
         if let Value::Integer(m) = &value {
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{}\n", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
+        }
+        if let Value::Integer32(m) = &value {
+            sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
+            sql = sql.replace(&format!(":{}", key), &format!("{}", m));
+
         }
         if let Value::Bool(m) = &value {
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{}\n", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
         }
         if let Value::BareString(m) = &value {
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{}\n", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
         }
         if let Value::StringArray(list) =&value{
 
@@ -112,9 +98,6 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{} ", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
         }
         if let Value::IntegerArray(list) =&value{
 
@@ -129,9 +112,20 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
             sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
             sql = sql.replace(&format!(":{}", key), &format!("{}", m));
 
-            // sql = re_key.replace_all(&sql, format!("{}\n", m).as_str()).to_string();
-            // sql = re_key2.replace_all(&sql, format!("{})", m).as_str()).to_string();
-            // sql = re_key3.replace_all(&sql, format!("{},", m).as_str()).to_string();
+        }
+        if let Value::Integer32Array(list) =&value{
+
+            let mut m = String::new();
+
+            for (i, item) in list.iter().enumerate() {
+                if i > 0 {
+                    m.push_str(", ");
+                }
+                m.push_str(format!("{}", item).as_str());
+            }
+            sql = sql.replace(&format!("#{}#", key), &format!("{}", m));
+            sql = sql.replace(&format!(":{}", key), &format!("{}", m));
+
         }
     }
     // sql = sql.replace("'", "''");
